 <?php 
	class DWSApi {
		private $surl = null;
		private $key = null;
		private $secret = null;
				
		function __construct($surl, $skey, $ssecret) {
			$this->surl=$surl;
			$this->key=$skey;
			$this->secret=$ssecret;
			$this->authtype="hmac1";
		}
		
		private function call($mth, $res, $data){
			$curl = curl_init();			
			curl_setopt($curl, CURLOPT_URL, $this->surl.$res);
			curl_setopt($curl, CURLOPT_CUSTOMREQUEST, $mth);
			$customHeaders = array();
			if ($data!=null){
				array_push($customHeaders,'Content-Type:application/json');
				curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($data));
			}			
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_USERAGENT, "Mozilla/4.0 (compatible; MSIE 5.01; Windows NT 5.0)");
			curl_setopt($curl, CURLOPT_TIMEOUT, 60);
			
			
			
			if ($this->authtype==""){
				curl_setopt($curl, CURLOPT_USERPWD, $this->key . ':' . $this->secret);
			}else if ($this->authtype=="hmac1"){
				$ctm=round(microtime(true)*1000);
				array_push($customHeaders,'X-DW-Authorization:' . 'HM1 ' . $this->key . ':' . base64_encode(hash_hmac('sha1', '' . $ctm, $this->secret, true)) . ':' . $ctm);
			}else{
				throw new Exception("Invalid authtype.");
			}
			if (sizeof($customHeaders)>0){
				curl_setopt($curl, CURLOPT_HTTPHEADER, $customHeaders);				
			}
			
			$response = json_decode(curl_exec($curl));
			$code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
			if ($code == 200) {
				return $response;
			}else{
				throw new Exception($response->message);
			}
		}
		
		public function get_account_info(){
			return $this->call("GET","account?request=info",null);
		}
		
		public function get_credit_transactions($days){
			return $this->call("GET","account?request=creditTransactions&days=".$days,null);
		}
		
		public function add_services($prop){
			return $this->call("PUT","account?request=addServices",$prop);
		}
		
		public function remove_services($prop){
			return $this->call("PUT","account?request=removeServices",$prop);
		}		
		
		public function get_agents(){
			return $this->call("GET","agents",null);
		}
		
		public function new_agent($prop){
			return $this->call("POST","agents",$prop)->id;
		}
		
		public function remove_agent($id){
			$this->call("DELETE","agents?id=".$id,null);
		}
		
		public function open_session($prop){
			return $this->call("POST","sessions",$prop);
		}
	}
 ?>
 
